@@ -3,8 +3,9 @@ Main interface for dms service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dms import (
+    from mypy_boto3_dms import (
         Client,
         DatabaseMigrationServiceClient,
         DescribeCertificatesPaginator,
@@ -28,7 +29,7 @@ Usage::
         ReplicationTaskRunningWaiter,
         ReplicationTaskStoppedWaiter,
         TestConnectionSucceedsWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -57,6 +58,7 @@ Usage::
     describe_replication_tasks_paginator: DescribeReplicationTasksPaginator = client.get_paginator("describe_replication_tasks")
     describe_schemas_paginator: DescribeSchemasPaginator = client.get_paginator("describe_schemas")
     describe_table_statistics_paginator: DescribeTableStatisticsPaginator = client.get_paginator("describe_table_statistics")
+    ```
 """
 from mypy_boto3_dms.client import (
     DatabaseMigrationServiceClient as Client,
