@@ -3,9 +3,11 @@ Main interface for dms service type definitions.
 
 Usage::
 
-    from mypy_boto3.dms.type_defs import AccountQuotaTypeDef
+    ```python
+    from mypy_boto3_dms.type_defs import AccountQuotaTypeDef
 
     data: AccountQuotaTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
