@@ -3,8 +3,11 @@ Main interface for dms service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dms import (
+
+    from mypy_boto3_dms import DatabaseMigrationServiceClient
+    from mypy_boto3_dms.waiter import (
         EndpointDeletedWaiter,
         ReplicationInstanceAvailableWaiter,
         ReplicationInstanceDeletedWaiter,
@@ -25,6 +28,7 @@ Usage::
     replication_task_running_waiter: ReplicationTaskRunningWaiter = client.get_waiter("replication_task_running")
     replication_task_stopped_waiter: ReplicationTaskStoppedWaiter = client.get_waiter("replication_task_stopped")
     test_connection_succeeds_waiter: TestConnectionSucceedsWaiter = client.get_waiter("test_connection_succeeds")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import List, TYPE_CHECKING
@@ -46,7 +50,7 @@ __all__ = (
 
 class EndpointDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.EndpointDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.EndpointDeleted)
+    [Waiter.EndpointDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.EndpointDeleted)
     """
 
     def wait(
@@ -57,13 +61,13 @@ class EndpointDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [EndpointDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.EndpointDeleted.wait)
+        [EndpointDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.EndpointDeleted.wait)
         """
 
 
 class ReplicationInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceAvailable)
+    [Waiter.ReplicationInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceAvailable)
     """
 
     def wait(
@@ -74,13 +78,13 @@ class ReplicationInstanceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceAvailable.wait)
+        [ReplicationInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceAvailable.wait)
         """
 
 
 class ReplicationInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceDeleted)
+    [Waiter.ReplicationInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceDeleted)
     """
 
     def wait(
@@ -91,13 +95,13 @@ class ReplicationInstanceDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceDeleted.wait)
+        [ReplicationInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceDeleted.wait)
         """
 
 
 class ReplicationTaskDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationTaskDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskDeleted)
+    [Waiter.ReplicationTaskDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskDeleted)
     """
 
     def wait(
@@ -109,13 +113,13 @@ class ReplicationTaskDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationTaskDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskDeleted.wait)
+        [ReplicationTaskDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskDeleted.wait)
         """
 
 
 class ReplicationTaskReadyWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationTaskReady documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskReady)
+    [Waiter.ReplicationTaskReady documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskReady)
     """
 
     def wait(
@@ -127,13 +131,13 @@ class ReplicationTaskReadyWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationTaskReady.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskReady.wait)
+        [ReplicationTaskReady.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskReady.wait)
         """
 
 
 class ReplicationTaskRunningWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationTaskRunning documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskRunning)
+    [Waiter.ReplicationTaskRunning documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskRunning)
     """
 
     def wait(
@@ -145,13 +149,13 @@ class ReplicationTaskRunningWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationTaskRunning.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskRunning.wait)
+        [ReplicationTaskRunning.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskRunning.wait)
         """
 
 
 class ReplicationTaskStoppedWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationTaskStopped documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskStopped)
+    [Waiter.ReplicationTaskStopped documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskStopped)
     """
 
     def wait(
@@ -163,13 +167,13 @@ class ReplicationTaskStoppedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationTaskStopped.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskStopped.wait)
+        [ReplicationTaskStopped.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskStopped.wait)
         """
 
 
 class TestConnectionSucceedsWaiter(Boto3Waiter):
     """
-    [Waiter.TestConnectionSucceeds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.TestConnectionSucceeds)
+    [Waiter.TestConnectionSucceeds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.TestConnectionSucceeds)
     """
 
     def wait(
@@ -180,5 +184,5 @@ class TestConnectionSucceedsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [TestConnectionSucceeds.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/dms.html#DatabaseMigrationService.Waiter.TestConnectionSucceeds.wait)
+        [TestConnectionSucceeds.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/dms.html#DatabaseMigrationService.Waiter.TestConnectionSucceeds.wait)
         """
